@@ -23,10 +23,8 @@ use crate::error::{
     InvalidStateError,
 };
 
-#[cfg(feature = "oauth-user-list")]
-use super::OAuthUserIter;
 use super::{
-    InsertableOAuthUserSession, OAuthUser, OAuthUserSession, OAuthUserSessionStore,
+    InsertableOAuthUserSession, OAuthUser, OAuthUserIter, OAuthUserSession, OAuthUserSessionStore,
     OAuthUserSessionStoreError,
 };
 
@@ -188,7 +186,6 @@ impl OAuthUserSessionStore for MemoryOAuthUserSessionStore {
             .cloned())
     }
 
-    #[cfg(feature = "oauth-user-list")]
     fn list_users(&self) -> Result<OAuthUserIter, OAuthUserSessionStoreError> {
         let internal = self.internal.lock().map_err(|_| {
             OAuthUserSessionStoreError::Internal(InternalError::with_message(
